==> 1.0.0-dev.1.tar.gz: lib/src/agent/http/http_request.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/http/dns_info.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/string_utils.dart';

import '../../../tingyun_flutter_plugin.dart';

class TingyunHttpClientRequest implements HttpClientRequest {

  HttpClientRequest _httpClientRequest;
  TingyunFlutterImpl _tingyun;
  // int _dnsDuration;
  // String _ipInfo;
  /// 用于标识一个网络，因为我们的跨应用是个固定值，所以这里弄了个uuid
  String _uuid;

  static final String _tingyunHeader = "X-Tingyun";
  //response X-Tingyun-Data

  TingyunHttpClientRequest(this._httpClientRequest, this._tingyun, String _headerValue, this._uuid){
    // _addTingyunHeader(_headerValue);
    Logger().d('TingyunHttpClientRequest');
    DnsInfo.setDnsInfo(uri.host);
  }

  /// 这里我们是否需要添加我们的header来实现跨应用追踪？
  void _addTingyunHeader(String headerValue) {
    // if(headerValue != null && this.headers.value(_tingyunHeader) == null){
    //   this.headers.add(_tingyunHeader, headerValue);
    // }
    if(!StringUtils.isStringNullEmptyOrWhitespace(headerValue) &&
        this.headers.value(_tingyunHeader) == null){
      this.headers.add(_tingyunHeader, headerValue);
    }
  }

  @override
  void abort([Object exception, StackTrace stackTrace]) {
    _httpClientRequest.addError(exception, stackTrace);
  }

  @override
  bool get bufferOutput => _httpClientRequest.bufferOutput;

  @override
  set bufferOutput(bool _bufferOutput)  => _httpClientRequest.bufferOutput = _bufferOutput;

  @override
  int get contentLength => _httpClientRequest.contentLength;

  @override
  set contentLength(int _contentLength) =>_httpClientRequest.contentLength = _contentLength;

  @override
  Encoding get encoding => _httpClientRequest.encoding;

  @override
  set encoding(Encoding value) => _httpClientRequest.encoding = value;

  @override
  bool get followRedirects => _httpClientRequest.followRedirects;

  @override
  set followRedirects(bool value) => _httpClientRequest.followRedirects = value;

  @override
  int get maxRedirects => _httpClientRequest.maxRedirects;

  @override
  set maxRedirects(int value) => _httpClientRequest.maxRedirects = value;

  @override
  bool get persistentConnection => _httpClientRequest.persistentConnection;

  @override
  set persistentConnection(bool value) =>
      _httpClientRequest.persistentConnection = value;

  @override
  void add(List<int> data) {
    _httpClientRequest.add(data);
  }

  @override
  void addError(Object error, [StackTrace stackTrace]) {
    _httpClientRequest.addError(error, stackTrace);
  }

  @override
  Future addStream(Stream<List<int>> stream) {
    return _httpClientRequest.addStream(stream);
  }

  @override
  Future<HttpClientResponse> close() async{
    //无论是否是跨应用的我们的header的，我们都监控？
    // if (this.headers.value(_tingyunHeader) != null) {
      TYWebRequestTiming timing = _tingyun.createWebRequestTiming(
          _uuid, _httpClientRequest.uri.toString());

      timing.start();
      try {
        HttpClientResponse response = await _httpClientRequest.close();

        // int dnsDura = DnsInfo.getDnsDuration(uri.host);
        // String ip = DnsInfo.getIpAddress(uri.host);
        // timing.withDnsInfo(dnsDura, ip);
        // timing.stopWebRequestTiming(response.statusCode, response.reasonPhrase);
        timing.stop(response.statusCode);

        return response;
      } catch (error) {
        // timing.stopWebRequestTiming(-1, error.toString());
        timing.stop(-1);

        throw error;
      }
    // } else {
    //   return await _httpClientRequest.close();
    // }
  }

  @override
  HttpConnectionInfo get connectionInfo => _httpClientRequest.connectionInfo;

  @override
  List<Cookie> get cookies => _httpClientRequest.cookies;

  @override
  Future<HttpClientResponse> get done => _httpClientRequest.done;

  @override
  Future flush() {
    _httpClientRequest.flush();
  }

  @override
  HttpHeaders get headers => _httpClientRequest.headers;

  @override
  String get method => _httpClientRequest.method;

  @override
  Uri get uri => _httpClientRequest.uri;

  @override
  void write(Object obj) {
    _httpClientRequest.write(obj);
  }

  @override
  void writeAll(Iterable objects, [String separator = ""]) {
    _httpClientRequest.writeAll(objects, separator);
  }

  @override
  void writeCharCode(int charCode) {
    _httpClientRequest.writeCharCode(charCode);
  }

  @override
  void writeln([Object obj = ""]) {
    _httpClientRequest.writeln(obj);
  }
}

==> 2.1.0.tar.gz: lib/src/agent/http/http_request.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/http/dns_info.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/string_utils.dart';

import '../../../tingyun_flutter_plugin.dart';

class TingyunHttpClientRequest implements HttpClientRequest {

  HttpClientRequest _httpClientRequest;
  TingyunFlutterImpl? _tingyun;
  // int _dnsDuration;
  // String _ipInfo;
  /// 用于标识一个网络，因为我们的跨应用是个固定值，所以这里弄了个uuid
  String _uuid;

  static final String _tingyunHeader = "X-Tingyun";
  //response X-Tingyun-Data

  TingyunHttpClientRequest(this._httpClientRequest, this._tingyun, String _headerValue, this._uuid){
    // _addTingyunHeader(_headerValue);
    Logger().d('TingyunHttpClientRequest');
    DnsInfo.setDnsInfo(uri.host);
  }

  /// 这里我们是否需要添加我们的header来实现跨应用追踪？
  void _addTingyunHeader(String headerValue) {
    // if(headerValue != null && this.headers.value(_tingyunHeader) == null){
    //   this.headers.add(_tingyunHeader, headerValue);
    // }
    if(!StringUtils.isStringNullEmptyOrWhitespace(headerValue) &&
        this.headers.value(_tingyunHeader) == null){
      this.headers.add(_tingyunHeader, headerValue);
    }
  }

  @override
  void abort([Object? exception, StackTrace? stackTrace]) {
    _httpClientRequest.addError(exception!, stackTrace);
  }

  @override
  bool get bufferOutput => _httpClientRequest.bufferOutput;

  @override
  set bufferOutput(bool _bufferOutput)  => _httpClientRequest.bufferOutput = _bufferOutput;

  @override
  int get contentLength => _httpClientRequest.contentLength;

  @override
  set contentLength(int _contentLength) =>_httpClientRequest.contentLength = _contentLength;

  @override
  Encoding get encoding => _httpClientRequest.encoding;

  @override
  set encoding(Encoding value) => _httpClientRequest.encoding = value;

  @override
  bool get followRedirects => _httpClientRequest.followRedirects;

  @override
  set followRedirects(bool value) => _httpClientRequest.followRedirects = value;

  @override
  int get maxRedirects => _httpClientRequest.maxRedirects;

  @override
  set maxRedirects(int value) => _httpClientRequest.maxRedirects = value;

  @override
  bool get persistentConnection => _httpClientRequest.persistentConnection;

  @override
  set persistentConnection(bool value) =>
      _httpClientRequest.persistentConnection = value;

  @override
  void add(List<int> data) {
    _httpClientRequest.add(data);
  }

  @override
  void addError(Object error, [StackTrace? stackTrace]) {
    _httpClientRequest.addError(error, stackTrace);
  }

  @override
  Future addStream(Stream<List<int>> stream) {
    return _httpClientRequest.addStream(stream);
  }

  @override
  Future<HttpClientResponse> close() async{
    //无论是否是跨应用的我们的header的，我们都监控？
    // if (this.headers.value(_tingyunHeader) != null) {
      TYWebRequestTiming timing = _tingyun!.createWebRequestTiming(
          _uuid, _httpClientRequest.uri.toString());

      timing.start();
      try {
        HttpClientResponse response = await _httpClientRequest.close();

        // int dnsDura = DnsInfo.getDnsDuration(uri.host);
        // String ip = DnsInfo.getIpAddress(uri.host);
        // timing.withDnsInfo(dnsDura, ip);
        // timing.stopWebRequestTiming(response.statusCode, response.reasonPhrase);
        timing.stop(response.statusCode);

        return response;
      } catch (error) {
        // timing.stopWebRequestTiming(-1, error.toString());
        timing.stop(-1);

        throw error;
      }
    // } else {
    //   return await _httpClientRequest.close();
    // }
  }

  @override
  HttpConnectionInfo? get connectionInfo => _httpClientRequest.connectionInfo;

  @override
  List<Cookie> get cookies => _httpClientRequest.cookies;

  @override
  Future<HttpClientResponse> get done => _httpClientRequest.done;

  @override
  Future flush() {
    return _httpClientRequest.flush();
  }

  @override
  HttpHeaders get headers => _httpClientRequest.headers;

  @override
  String get method => _httpClientRequest.method;

  @override
  Uri get uri => _httpClientRequest.uri;

  @override
  void write(Object? obj) {
    _httpClientRequest.write(obj);
  }

  @override
  void writeAll(Iterable objects, [String separator = ""]) {
    _httpClientRequest.writeAll(objects, separator);
  }

  @override
  void writeCharCode(int charCode) {
    _httpClientRequest.writeCharCode(charCode);
  }

  @override
  void writeln([Object? obj = ""]) {
    _httpClientRequest.writeln(obj);
  }
}
